@@ -34,7 +34,6 @@ public class PeakAnnotator {
     private String m_PeakFileExtension;
     private String m_prefix;
     private int m_numRandomDatasets;
-    private Boolean m_Use5EndDistance;
     
     private String m_GeneFileName;
     private String m_GeneFileNoExtension;
@@ -75,9 +74,8 @@ public class PeakAnnotator {
     }
     
 	public void Init(String utility, String peakFile, String geneFile, String outputDir, String symbolFile,boolean mustStrand,
-			String formattype,String geneType,String prefix,String chrSizeFile,int numRandom,Boolean distance) throws Exception
+			String formattype,String geneType,String prefix,String chrSizeFile,int numRandom) throws Exception
 	{	
-		m_Use5EndDistance=distance;
 		m_numRandomDatasets = numRandom;
 		if(!prefix.equals(""))
 		{
@@ -565,25 +563,23 @@ public class PeakAnnotator {
 		                        		//if the containing gene overlaps - we want to print it but this is not a downstream gene
 		                        		p.FindOverlapGeneElement(vecPeak.get(i),overlapPosition);
 		                        		PrintOverlapPosition(p,vecPeak.get(i),overlapPosition);
-		                        		numOfOverlapGenes ++;
-		                        		if(!summary.contains(ClosestDownstreamNegGene.GetSymbol()))
-		                        			summary += ClosestDownstreamNegGene.GetSymbol() + ",";
+		                        		numOfOverlapGenes ++;		                     
+		                        		if(!summary.contains(p.GetSymbol()))		                       			
+		                        			summary += p.GetSymbol() + ",";	 		                        		
 		                        	}
 		                        	else if (p.m_Strand.equals(Strand.Strand_Negative))
 		                        	{
 			                		 //if a container is not overlapping then it must be closer to the peak
 			                         //but just in case we check it again.
 			                         //for negative strand the distance is calculated as the Gene's end point - peak's Central Point
-		                        	   int newDistance=-1;
-		                        	   if(m_Use5EndDistance)
-		                        		   newDistance = Math.abs(p.Minus(vecPeak.get(i)));
-		                        	   else
-		                        		   newDistance = Math.abs(p.MinusTSS(vecPeak.get(i)));
-			                           if(ClosestDownstreamNegDistance > newDistance)
-			                           {
-			                                   ClosestDownstreamNegDistance = newDistance;
-			                                   ClosestDownstreamNegGene = p;    
-			                           }
+		                        
+		                        	int newDistance = Math.abs(p.Minus(vecPeak.get(i)));
+		                        	   
+		                           if(ClosestDownstreamNegDistance > newDistance)
+		                           {
+		                                   ClosestDownstreamNegDistance = newDistance;
+		                                   ClosestDownstreamNegGene = p;    
+		                           }
 			                	    }  	
 		                        }
 	                        }
@@ -665,15 +661,8 @@ public class PeakAnnotator {
                     while(temp < vecGenes.size())
                     {
                             Position currentPosition = vecGenes.get(temp);
-                            int curDistance;
-                            if(m_Use5EndDistance)
-                            {
-                            	curDistance = currentPosition.Minus(vecPeak.get(i));       	
-                            }
-                            else
-                            {
-                            	curDistance = currentPosition.MinusTSS(vecPeak.get(i));
-                            }
+                        
+                            int	curDistance = currentPosition.Minus(vecPeak.get(i));       	
                             if(checkOverlap && vecPeak.get(i).Overlap(currentPosition))
                             {
                                 curDistance = 0;
@@ -686,15 +675,8 @@ public class PeakAnnotator {
                         temp++;
                         //if this condition is met there is no need to continue checking because
                         //there are no genes further to the right that can be closer
-                        
-                        if(m_Use5EndDistance)
-                        {
-
                         	if((currentPosition.m_Start >= stopIndex) || (currentPosition.m_Strand.equals(Strand.Strand_Positive)))
                         			break;
-                        }
-                        else if((currentPosition.m_Start >= stopIndex))
-                                break;
                     }
                             
                     closestPositionIndex --;
@@ -714,15 +696,7 @@ public class PeakAnnotator {
                     while(closestPositionIndex >= 0)
                     {
                         Position currentPosition = vecGenes.get(closestPositionIndex);
-                        int curDistance;
-                        if(m_Use5EndDistance)
-                        {
-                        	curDistance = currentPosition.Minus(vecPeak.get(i));
-                        }
-                        else
-                        {
-                        	curDistance = currentPosition.MinusTSS(vecPeak.get(i));
-                        }
+                        int	curDistance = currentPosition.Minus(vecPeak.get(i));
                         if(checkOverlap && vecPeak.get(i).Overlap(currentPosition))
                         {
                             curDistance = 0;
@@ -742,15 +716,7 @@ public class PeakAnnotator {
 	                        	Iterator<Position> itr2 =currentPosition.m_Containers.iterator();
 	                        	while(itr2.hasNext()){
 	                        		Position p = itr2.next();
-	                                if(m_Use5EndDistance)
-	                                {
-	                                	curDistance = p.Minus(vecPeak.get(i));
-	                                }
-	                                else
-	                                {
-	                                	curDistance = p.MinusTSS(vecPeak.get(i));
-	                                }
-	                        		
+	                               	curDistance = p.Minus(vecPeak.get(i));            
 	                                if(checkOverlap && vecPeak.get(i).Overlap(p))
 	                                {
 	                                        curDistance = 0;
